@@ -67,7 +67,7 @@ class quantum_lab():
             response = requests.get(f"http://sdt-api.qcc.svc.cluster.local/qcc/notebook/job/{jobID}", headers=headers) 
             data = response.json()
             p_status = data["jobStatus"]
-            print(f"Time: {time_num} / Status: {p_status}")
+            print(f"Time: {time_num} / Status: {p_status}", end='\r')
             if p_status == "Success" or p_status == "Failed":
                 break
             time_num += 1
